==> kdebase-3.4.1.tar.bz2: kdebase-3.4.1/klipper/historystringitem.h <==
// -*- Mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 8; -*-
/* This file is part of the KDE project
   Copyright (C) 2004  Esben Mose Hansen <kde@mosehansen.dk>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef _HISTORYSTRINGITEM_H_
#define _HISTORYSTRINGITEM_H_

#include <qstring.h>

#include "historyitem.h"

/**
 * A string entry in the clipboard history.
 */
class HistoryStringItem : public HistoryItem
{
public:
    HistoryStringItem( const QString& data );
    virtual ~HistoryStringItem() {}
    virtual const QString& text() const;
    virtual bool operator==( const HistoryItem& rhs) const {
        if ( const HistoryStringItem* casted_rhs = dynamic_cast<const HistoryStringItem*>( &rhs ) ) {
            return casted_rhs->m_data == m_data;
        }
        return false;
    }

    /**
     * Write object on datastream
     */
    virtual void write( QDataStream& stream ) const;

private:
    QString m_data;
};

inline const QString& HistoryStringItem::text() const { return m_data; }


#endif

==> kdebase-3.5.0.tar.bz2: kdebase-3.5.0/klipper/historystringitem.h <==
// -*- Mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 8; -*-
/* This file is part of the KDE project
   Copyright (C) 2004  Esben Mose Hansen <kde@mosehansen.dk>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef _HISTORYSTRINGITEM_H_
#define _HISTORYSTRINGITEM_H_

#include <qstring.h>

#include "historyitem.h"

/**
 * A string entry in the clipboard history.
 */
class HistoryStringItem : public HistoryItem
{
public:
    HistoryStringItem( const QString& data );
    virtual ~HistoryStringItem() {}
    virtual const QString& text() const;
    virtual bool operator==( const HistoryItem& rhs) const {
        if ( const HistoryStringItem* casted_rhs = dynamic_cast<const HistoryStringItem*>( &rhs ) ) {
            return casted_rhs->m_data == m_data;
        }
        return false;
    }

    /**
     * Write object on datastream
     */
    virtual void write( QDataStream& stream ) const;

private:
    QString m_data;
};

inline const QString& HistoryStringItem::text() const { return m_data; }


#endif
